
==========================
Leonardo leonardo-page-search
==========================

Allows customize page search includes.

.. contents::
    :local:

Installation
------------

.. code-block:: bash

    pip install leonardo-page-search

Read More
=========

* https://github.com/django-leonardo/django-leonardo
